function m=rowtotal(M,indx)
% rowtotal - compute rowtotal without deflating matrix
% 
% 
% CALL
%     m=rowtotal(M), OR:
%     m=rowtotal(M,indx)
%
% INPUT
%     M      : deflated matrix
% 
% NOTE
%     Elements will be converted to double before adding them together.
%     Matrix must have 2 or less dimensions.
%     m=rowtotal(M,indx) is equivalent to m=sum(full(M(:,indx)),2) 

if length(size(M))>2
    error('deflate/rowtotal require 2 dimensional matrix');
end

if nargin<2
    indx=(1:size(M,2));
end

NMAX=max(size(M,1),5*10^6); %Number of doubles that can be held in memory
CMAX=floor(NMAX/size(M,1)); %Number of columns that can be read in one go

m=zeros(size(M,1),1);
START =1;
while START<numel(indx)
    %define subset of max CMAX columns
    END=START-1+CMAX;
    END=min(END,numel(indx));
    subset=indx(START:END);
    
    %increase sum:
    data=subsref(M, substruct('()',{':',subset}));
    
    m=m+sum(double(data),2);
    
    START=END+1;
end

