function m=sum(M,dim)
% sum - compute rowtotal without deflating matrix
% 
% 
% CALL
%     m=rowtotal(M), OR:
%     m=rowtotal(M,indx)
%
% INPUT
%     M      : deflated matrix
% 
% NOTE
%     Elements will be converted to double before adding them together.
%     Matrix must have 2 or less dimensions.
%     m=rowtotal(M,indx) is equivalent to m=sum(full(M(:,indx)),2) 
% 
% EXAMPLE AND TEST
%     a=ones(2,3,4);
%     a(:)=1:numel(a);
%     a1=sum(a,2);
%     a=deflate(a);
%     a2=sum(a,2);
%     is_eq(a1,a2);
    
    
sz=size(M);

if nargin<2
    %  sum over first non-singleton dimension
    for dim=1:length(sz)
        if sz(dim)>1
            break
        end
    end
end

msz=sz;
msz(dim)=1;
m=zeros(msz);


%for each element, compute to which element it contributes
%  i,j,k
IND=cell(1,length(sz));
FIRST=1;
N=numel(M);
S=get(M,'segm');
while FIRST<=N

    %define first and last
    LAST=FIRST+S-1;
    LAST=min(LAST,N);
    %define index in M:
    M_indx=(FIRST:LAST)';
    %retrieve corresponding data
    data=M.data(M_indx);
    %get corresponding indices in M:    
    [IND{:}]=ind2sub(sz,M_indx);
    %ignore dimensiom "dim":
    plusindx=IND;
    plusindx(dim)=[];
    %create linear index in m
    m_indx=sub2ind(msz,plusindx{:});
    
    %do addition. Note vectorisition is not possible because m_indx
    %contains duplicate elements
    for k=1:length(m_indx)
        mm=m_indx(k);
        m(mm)=m(mm)+data(k);
    end
    
    %set new lower limit
    FIRST=LAST+1;
end


        

    