function [ISCLOSED,rng,OOB,newsz]=isclosedrange(ind,sz,DOASSIGN)
% isclosedrange - return true if ind refers to adjacent elements
% 
% INPUT
%     ind: general SUBSTRUCT index
%     sz:  size of object
%     
% OUTPUT
%     ISCLOSED: true if one or more closed ranges found
%     rng(Nx2): first and last element indices in datavector
%     OOB     : true if out of bound assignment. This also means that
%               dimension has been added or current dimension is grown.
%               Otherwise an error will occur.
%     newsz   : new dimension of object in cas of OOB assignment

%Check syntax
%The expected assignment/reference is: 
%     ARRAY(I1,I2,...)
%The corresponding substruct is:
%     struct('type','()','subs',{[I1],[I2],...})
if ind(1).type(1)~='(' || length(ind)>1
    error('Subscripts in compressed matrix should be of form: M(I1,I2,I2,...)');    
end

OOB=false;
newsz=[];

%Possibility 1
% M_DEFLATE(:)=data; ==> ind.subs=':'
if length(ind.subs)==1 && strcmp(ind.subs,':')
    %closed range
    ISCLOSED=true;
    rng=[1;prod(sz)];    
    return
end

% ind.type: ()
% ind.subs: {indx1, indx2 etc}
if ~strcmp(ind.subs{1},':')
    ISCLOSED=false;
    rng=[];   
    return
end

%return ranges
ind.subs{1} = 1; %compute start of each range
subscript   = getSubscript(ind,sz);
linStart    = sub2indVector(sz,subscript{:});

ind.subs{1}=sz(1); %compute end of each range
[subscript,OOB] = getSubscript(ind,sz);
linEnd          = sub2indVector(sz,subscript{:});

if OOB 
    if  length(subscript)<length(sz)    
        %Index exceeds matrix dimensions
        error('Out of bound incomplete index');
    end    
    %At least 1 dimension has grown
    %Redefine size:
    newsz=zeros(1,length(subscript));
    for k=1:length(subscript)
        newsz(k)=max(subscript{k});        
    end
    %strip singleton dimensions
    for k=length(newsz):-1:(length(sz)+1)
        if newsz(k)~=1
            break
        end
        newsz(k)=[];
    end
    %apply maximum of old and new size
    for k=1:length(sz)
        newsz(k)=max(newsz(k),sz(k));
    end    
end 

ISCLOSED=true;
rng=[linStart(:)';linEnd(:)'];


