function [M,nElm]=range2blk(rng,bSize)
%get block indices for blocks that overlap with ranges
% 
% INPUT
%     rng(2,N): set of ranges
% 	bSize: segment size
% 	
% OUTPUT
%    M
%     row 1: start index (relative to compressed vector)
%     row 2: end index (relative to compressed vector)
% 	  row 3: segment index (sorted)
%     row 4: start index (in returned vector)
%     row 5: end index (in returned vector)
   
% allblks=[];
% for thisrng=rng
%     thisBlk=1+floor((thisrng-1)/bSize);
%     blks=(thisBlk(1):thisBlk(2))';
%     allblks=cat(1,allblks;blks);
% end
% unblks=unique(allblks);

newrng=[];
newseg=[];
for thisrng=rng
	thisBlk = 1+floor((thisrng-1)/bSize);
	blks    = (thisBlk(1):thisBlk(2));
	if length(blks)>1
		%split range over multiple segments
		insertrng= [thisrng(1);bSize*blks(1)];%first range
		for bb=blks(2:end-1)
			insertrng=cat(2,insertrng,[1+(bb-1)*bSize;bb*bSize]);
		end
		insertrng=cat(2,insertrng,[1+(blks(end)-1)*bSize;thisrng(2)]);
		newrng=cat(2,newrng,insertrng);
	else
		%do not split range
		newrng=cat(2,newrng,thisrng);
	end
	%append corresponding segments
	newseg=cat(2,newseg,blks);
end
%newrng: (2xN): ranges that do not cross segment border
%newseg: (1xN): corresponding segments

numelm=1+newrng(2,:)-newrng(1,:);
nElm=sum(numelm);
storestrt=cumsum([1,numelm(1:end-1)]);
storeend =cumsum(numelm);

M=[newrng;newseg;storestrt;storeend];
[dummy,indx]=sort(M(3,:));
M=M(:,indx);




    
	


