function defaultOptions = varargin2struct(defaultOptions,ValidProps,varargin)
% varargin2struct - Convert parameter-value combinations to structure
% 
% CALL:
%  defaultOptions = varargin2struct(defaultOptions,ValidProps,...
%                     PROPERTY1,VALUE1,PROPERTY2,VALUE2,...)
%  defaultOptions = varargin2struct(defaultOptions,ValidProps,...
%                     PROPERTY1,VALUE1,OPTSTRUCT,...)
%     
% INPUT:
%     defaultOptions: 
%         Struct with default values
%     ValidProps:
%         Allowable fields (cell array)
%     PROPERTY,VALUE:
%         Property-Value pairs, and/or
%     OPTSTRUCT:      Option structure that stores property value pairs
%     +----PROPERTY1=VALUE1
%     +----PROPERTY2=VALUE2
% 
% OUTPUT:
% 	  Options: 
%         structure identical to defaultOptions, but appriate fields over
%         overwritten with property value pairs. 
%
% EXAMPLE:
%  function do_some(varargin)
%  defaultOptions=struct('a',1,'b',2);
%  Options=varargin2struct(defaultOptions,fieldnames(defaultOptions),varargin{:});
% 
%   Copyright 2006-2015 Modelit, www.modelit.nl
% 
% See also: getproperty


%only makes a difference if varargin is empty.
if isempty(defaultOptions)
    defaultOptions=struct;
end

argnr=1;
while argnr<=length(varargin)
    if isempty(varargin{argnr})
        %WIJZ ZIJPP JAN 2008
        %treat [] as an empty structure
        argnr=argnr+1; %"eat" 1 argument
    elseif isstruct(varargin{argnr}) 
        %if property name is structure ==> decompose in fieldname value
        %pairs
        s=varargin{argnr}; 
        prop_names  =fieldnames(s);%get the fieldnames
        for k=1:length(prop_names) %cycle through names
            fld=prop_names{k};
            %Get full property name
            %     property=getproperty(varargin{argnr},ValidProps,ValidPropsLC);
            property=getproperty(fld,ValidProps);
            if isstruct(s.(fld))
                
                %NEW: OCT 2005, ZIJPP
                %supplied value is a structure: preserve fields of
                %defaultOptions.(property) that are not named in s.(fld)
                
                
                if isfield(defaultOptions,property)
                    %field also exist in default options, overwrite values
                    %given in argument, assume all fields in structure are
                    %ok
                    defaultOptions.(property)=...
                        varargin2struct(defaultOptions.(property),fieldnames(s.(fld)), s.(fld));
                else
                    %field does not exist use new value
                    defaultOptions.(property)= s.(fld);
                end
            else
                defaultOptions.(property)= s.(fld);
            end
        end
        argnr=argnr+1; %"eat" 1 argument
    else        
        property=getproperty(varargin{argnr},ValidProps);
        defaultOptions.(property)=varargin{argnr+1};
        argnr=argnr+2; %"eat" 2 arguments
    end
end

